@@ -32,7 +32,6 @@ from debusine.artifacts.models import DebianAutopkgtestResultStatus as rs
 from debusine.artifacts.models import (
     DebianAutopkgtestSource,
     DebianBinaryPackage,
-    DebianBinaryPackages,
     DebianSourcePackage,
     DebianUpload,
 )
@@ -48,7 +47,7 @@ from debusine.tasks.models import (
     LookupMultiple,
     WorkerType,
 )
-from debusine.tasks.server import ArtifactInfo
+from debusine.tasks.server import ArtifactInfo, CollectionInfo
 from debusine.tasks.tests.helper_mixin import (
     ExternalTaskHelperMixin,
     FakeTaskDatabase,
@@ -68,7 +67,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             "source_artifact": 5,
             "binary_artifacts": [10, 11],
         },
-        "host_architecture": "amd64",
+        "build_architecture": "amd64",
         "environment": "debian/match:codename=bookworm",
     }
 
@@ -123,8 +122,8 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
                 (LookupMultiple.parse_obj([10, 11]), None): [
                     ArtifactInfo(
                         id=10,
-                        category=ArtifactCategory.BINARY_PACKAGES,
-                        data=self.create_binary_packages_data("hello"),
+                        category=ArtifactCategory.BINARY_PACKAGE,
+                        data=self.create_binary_package_data("hello"),
                     ),
                     ArtifactInfo(
                         id=11,
@@ -329,10 +328,10 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
         with self.assertRaises(TaskConfigError):
             self.configure_task(override={"something": "test"})
 
-    def test_configure_host_architecture_is_required(self) -> None:
-        """Missing required field "host_architecture": raise exception."""
+    def test_configure_build_architecture_is_required(self) -> None:
+        """Missing required field "build_architecture": raise exception."""
         with self.assertRaises(TaskConfigError):
-            self.configure_task(remove=["host_architecture"])
+            self.configure_task(remove=["build_architecture"])
 
     def test_configure_environment_is_required(self) -> None:
         """Missing required field "environment": raise exception."""
@@ -513,7 +512,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
 
     def test_can_run_on(self) -> None:
         """can_run_on returns True if unshare and autopkgtest are available."""
-        architecture = self.task.data.host_architecture
+        architecture = self.task.data.build_architecture
         self.assertTrue(
             self.task.can_run_on(
                 {
@@ -580,18 +579,6 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             deb_control_files=[],
         )
 
-    def create_binary_packages_data(
-        self, srcpkg_name: str
-    ) -> DebianBinaryPackages:
-        """Create sample `debian:binary-packages` artifact data."""
-        return DebianBinaryPackages(
-            srcpkg_name=srcpkg_name,
-            srcpkg_version="1.0",
-            version="1.0",
-            architecture="amd64",
-            packages=[],
-        )
-
     def create_upload_data(self, name: str) -> DebianUpload:
         """Create sample `debian:upload` artifact data."""
         return DebianUpload(
@@ -630,11 +617,6 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
                 category=ArtifactCategory.BINARY_PACKAGE,
                 data=self.create_binary_package_data("hello"),
             ),
-            ArtifactInfo(
-                id=11,
-                category=ArtifactCategory.BINARY_PACKAGES,
-                data=self.create_binary_packages_data("hello"),
-            ),
             ArtifactInfo(
                 id=12,
                 category=ArtifactCategory.UPLOAD,
@@ -649,11 +631,6 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
                 category=ArtifactCategory.BINARY_PACKAGE,
                 data=self.create_binary_package_data("context"),
             ),
-            ArtifactInfo(
-                id=3,
-                category=ArtifactCategory.BINARY_PACKAGES,
-                data=self.create_binary_packages_data("context"),
-            ),
             ArtifactInfo(
                 id=4,
                 category=ArtifactCategory.UPLOAD,
@@ -666,8 +643,8 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
             AutopkgtestDynamicData(
                 environment_id=1,
                 input_source_artifact_id=5,
-                input_binary_artifacts_ids=[10, 11, 12],
-                input_context_artifacts_ids=[2, 3, 4],
+                input_binary_artifacts_ids=[10, 12],
+                input_context_artifacts_ids=[2, 4],
                 subject="hello",
                 parameter_summary="hello_1.0 (amd64)",
                 runtime_context="amd64:unshare",
@@ -699,8 +676,8 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
         ] = [
             ArtifactInfo(
                 id=2,
-                category=ArtifactCategory.BINARY_PACKAGES,
-                data=self.create_binary_packages_data("context"),
+                category=ArtifactCategory.BINARY_PACKAGE,
+                data=self.create_binary_package_data("context"),
             ),
             ArtifactInfo(
                 id=3,
@@ -835,6 +812,67 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
         )
         self.assertIn("--copy=/tmp/key.asc:/etc/apt/keyrings/key.asc", cmdline)
 
+    def test_cmdline_extra_debusine_repositories(self) -> None:
+        """Extra repositories can be hosted by Debusine."""
+        self.configure_task(
+            override={
+                "extra_repositories": [{"suite": "trixie-local@debian:suite"}]
+            }
+        )
+        self.task_db.single_collection_lookups[
+            ("trixie-local@debian:suite", None)
+        ] = CollectionInfo(
+            id=1,
+            scope_name="scope",
+            workspace_name="workspace",
+            category=CollectionCategory.SUITE,
+            name="trixie-local",
+            data={"components": ["main"]},
+        )
+        self.task_db.settings["DEBUSINE_DEBIAN_ARCHIVE_PRIMARY_FQDN"] = (
+            "deb.example.com"
+        )
+        self.task_db.suite_signing_keys[1] = "\n".join(
+            (
+                "-----BEGIN PGP PUBLIC KEY BLOCK-----",
+                "",
+                "ABCDEFGHI",
+                "-----END PGP PUBLIC KEY BLOCK-----",
+            )
+        )
+        self.set_dynamic_data()
+        debusine_mock = self.mock_debusine()
+        self.mock_image_download(debusine_mock)
+        self.task._prepare_executor()
+        destination = self.create_temporary_directory()
+
+        self.task.write_extra_repository_config("trixie", destination)
+        cmdline = self.task._cmdline()
+
+        self.assertEqual(self.task.extra_repository_keys, [])
+        [extra_repository_source] = self.task.extra_repository_sources
+        self.assertEqual(
+            extra_repository_source.read_text(),
+            textwrap.dedent(
+                """\
+                Types: deb
+                URIs: http://deb.example.com/scope/workspace
+                Suites: trixie-local
+                Components: main
+                Signed-By:
+                 -----BEGIN PGP PUBLIC KEY BLOCK-----
+                 .
+                 ABCDEFGHI
+                 -----END PGP PUBLIC KEY BLOCK-----
+                """
+            ),
+        )
+        self.assertIn(
+            f"--copy={extra_repository_source}:"
+            f"/etc/apt/sources.list.d/{extra_repository_source.name}",
+            cmdline,
+        )
+
     def test_cmdline_apt_default_release_not_included(self) -> None:
         """Command line NOT include "--apt-default-release={distribution}."""
         self.mock_executor()
@@ -1255,7 +1293,7 @@ class AutopkgtestTests(ExternalTaskHelperMixin[Autopkgtest], TestCase):
                         pydantic.AnyUrl, "https://some-url.com/test"
                     ),
                 ),
-                architecture=self.task.data.host_architecture,
+                architecture=self.task.data.build_architecture,
                 distribution="debian:bookworm",
             ),
         )
